# 锐派(rypi)

锐派(rypi) 是由锐白开发的派神(python)工具包，包含多种网络工具和实用程序模块。

## 组件介绍

### 锐网(ryweb)
网站服务器管理工具，一个集成的 Web 服务器管理包，支持以下组件：
- Nginx
- PostgreSQL
- ArangoDB
- SeaweedFS
- Conda
- Uvicorn
- FastAPI
- PHP

如果需要在网络上搭建网站服务器，在使用锐网(ryweb)前，请先获得一台服务器，推荐使用 [雨云](https://www.rainyun.com/OTMyMTQ2_)，这家服务商的云服务器很实惠。

### 锐鸥(ryo)
一款网站应用工具，包含服务端（发行商）、代理端（运营商），代理端为共享软件，由运营商（站长或平台运营者）使用，免费版只能使用基础功能，部分功能需要付费解锁。任何个人或企业都可以通过锐鸥(ryo)运营自己的内容平台，无需具备代码编程相关的知识，只需买一台服务器启动程序，选择开放相应的应用与工具供平台用户使用就可以坐享收益。

### 锐通(ryto)
通用/公用(Util)函数/工具库(Tools)。

### 锐代(rydy)
一款网络数据抓包代理工具。

### 锐辅(ryfu)
一款辅助工具，可用于执行日常自动任务，如：
- 游戏辅助
- 广告辅助
- 应用辅助

### 锐爬(rypa)
一款网络内容爬取工具，如：
- 新闻内容
- 电影内容
- 电商内容

### 锐库(ryku)
一款简易数据库

### 锐本(ryben)
一款简易文本数据库

### 锐窗(rywin)
用派神(python)开发的锐派(rypi)图形窗口，方便在图形界面系统(PyQt)或终端(Urwid)进行图形可视化窗口创建

### 锐爱(ryapp)
一款简易应用生成工具

## 使用流程

安装锐派(rypi): pip install rypi

安装依赖库: pip install requests fonttools pyotp

## 联系信息

- **更多内容**: 请前往 [锐码官网](http://rymaa.cn) 查阅
- **Pypi 源包仓库**: [https://pypi.org/project/rypi](https://pypi.org/project/rypi)
- **Gitee 源码仓库**: [https://gitee.com/rybby/rypi](https://gitee.com/rybby/rypi)
- **作者**: 锐白
- **主页**: [rybby.cn](http://rybby.cn), [ry.rymaa.cn](http://ry.rymaa.cn)
- **邮箱**: rybby@163.com

## 许可证信息

### 主要许可证

**版权所有 2025 锐码[rymaa.cn](http://rymaa.cn) - rymaa_cn@163.com**

本软件采用锐码署名传播许可证(RSPL)授权。详情请见 LICENSE 或 LICENSE-EN 文件。

#### Python 标准库模块许可证信息

| 模块 | 许可证 | 备注 |
|:---:|:---:|:---:|
| os | PSF License | Python核心模块 |
| sys | PSF License | Python核心模块 |
| argparse | PSF License | 原为第三方库，后纳入标准库 |
| importlib | BSD 3-Clause | 基于PEP 302实现 |
| importlib.util | BSD 3-Clause | importlib的实用工具 |
| random | PSF License | 基于Mersenne Twister算法 |
| string | PSF License | 字符串常量模块 |
| base64 | PSF License | RFC 3548实现 |
| hashlib | PSF License | 基于OpenSSL的哈希库 |
| pkgutil | PSF License | 包工具扩展模块 |
| pathlib | Apache 2.0 | 面向对象的文件系统路径 |
| inspect | PSF License | 自省工具模块 |
| shlex | PSF License | 简单词法分析 |

## 许可证兼容性

所有这些许可证都是**开源友好**且**商业友好**的：

### 共同特点：
- ✅ 允许商业使用
- ✅ 允许修改
- ✅ 允许分发
- ✅ 不要求衍生作品开源

### 主要要求：
- 📝 保留原始版权声明
- 📝 在分发时包含许可证文本

## 实际使用建议

在您的锐派(rypi)项目中：

- **合规使用**：所有这些模块都可以在商业项目中使用
- **无需担心**：Python 标准库的许可证设计就是为了方便开发者
- **建议做法**：在您的项目 LICENSE 文件中 或 README.md 文件中提及使用了 Python 标准库

## 技术支持

如有问题或建议，请通过以下方式联系：
- 邮箱: rybby@163.com
- 官网: 锐码[rymaa.cn](http://rymaa.cn)

---

*版权所有 2025 锐码[rymaa.cn](http://rymaa.cn)*